==> quassel_0.5.0.orig.tar.gz: quassel-0.5.0/src/uisupport/resizingstackedwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2005-09 by the Quassel Project                          *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "resizingstackedwidget.h"

ResizingStackedWidget::ResizingStackedWidget(QWidget *parent) : QStackedWidget(parent)
{
  connect(this, SIGNAL(currentChanged(int)), SLOT(indexChanged(int)));
}

QSize ResizingStackedWidget::sizeHint() const {
  QWidget *widget = currentWidget();
  if(!widget)
    return QSize();
  return widget->sizeHint();
}

void ResizingStackedWidget::indexChanged(int index) {
  Q_UNUSED(index)
  updateGeometry();
}

==> quassel_0.13.1.orig.tar.gz: quassel-0.13.1/src/uisupport/resizingstackedwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2005-2019 by the Quassel Project                        *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include "resizingstackedwidget.h"

ResizingStackedWidget::ResizingStackedWidget(QWidget *parent) : QStackedWidget(parent)
{
    connect(this, SIGNAL(currentChanged(int)), SLOT(indexChanged(int)));
}


QSize ResizingStackedWidget::sizeHint() const
{
    QWidget *widget = currentWidget();
    if (!widget)
        return QSize();
    return widget->sizeHint();
}


void ResizingStackedWidget::indexChanged(int index)
{
    Q_UNUSED(index)
    updateGeometry();
}
